Package: circda
Type: Package
Title: Circular Data Analysis
Version: 1.0
Date: 2026-07-20
Authors@R: person("Michail", "Tsagris", role = c("aut", "cre"), email = "mtsagris@uoc.gr")
Author: Michail Tsagris [aut, cre]
Maintainer: Michail Tsagris <mtsagris@uoc.gr>
Depends: R (>= 4.0)
Imports: circular, Directional, graphics, rangen, Rfast, stats
Suggests: Rfast2
Description: Functions to perform maximum likelihood estimation, model-based clustering, discriminant and regression analysis with a circular response variable. <doi:10.1080/01621459.2019.1585249>.   
License: GPL (>= 2)
NeedsCompilation: no
Packaged: 2026-07-20 19:37:35 UTC; mtsag
Repository: CRAN
Date/Publication: 2026-07-29 18:30:02 UTC
