rcirc <- function(n, rads = TRUE, mu, kappa, rho, type = "vm") {

  if ( type == "vm" ) {
    u <- Directional::rvonmises(n, mu, kappa, rads = TRUE)
  } else if ( type == "cp" ) {
    u <- Directional::rcircpurka(n, mu, kappa, rads = TRUE)
  } else if ( type == "pn" ) {
    mu <- kappa * cbind( cos(mu), sin(mu) )
    u <- Directional::rspml(n, mu, rads = TRUE)
  } else if ( type == "gcpc" ) {
    u <- Directional::rgcpc(n, omega = mu, g = kappa, rho = rho, rads = TRUE)
  } else if ( type == "cipc" ) {
    u <- Directional::rcipc(n, omega = mu, g = kappa, rads = TRUE)
  }
  if ( !rads )  u <- u / pi * 180
  u
}


