\name{circplot}
\alias{circplot}
\title{
Circular histogram
}

\description{
Histogram of circular data.
}

\usage{
circplot(u, mu = NULL, rads = TRUE, col = 3, lwd = 2)
}

\arguments{
\item{u}{
A vector with the circular data expressed in radians, or angles.
}
\item{mu}{
The estimated circular mean or a circular location estimate. If this
is not available the circular mean is caclulated internally.
}
\item{rads}{
If the data are expressed in angles set this to FALSE.
}
\item{col}{
The color of the arrow pointing the mean direction.
}
\item{lwd}{
The thickness of the above arrow of the circular mean.
}
}

%\details{
%}

\value{
A circular histogram.
}

%\references{
%}

\author{
Michail Tsagris.

R implementation and documentation: Michail Tsagris \email{mtsagris@uoc.gr}.
}

%\note{
%%  ~~further notes~~
%}

\seealso{
\code{ \link{circ.mle}
}
}

\examples{
u <- rnorm(100, rnorm(3, 0.2) )
circplot(u, 3)
}

